from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class DataIconKey2(Enum):
    """An enumeration representing different categories.

    :cvar TASK: "task"
    :vartype TASK: str
    :cvar EMAIL: "email"
    :vartype EMAIL: str
    :cvar MEETING: "meeting"
    :vartype MEETING: str
    :cvar DEADLINE: "deadline"
    :vartype DEADLINE: str
    :cvar CALL: "call"
    :vartype CALL: str
    :cvar LUNCH: "lunch"
    :vartype LUNCH: str
    :cvar CALENDAR: "calendar"
    :vartype CALENDAR: str
    :cvar DOWNARROW: "downarrow"
    :vartype DOWNARROW: str
    :cvar DOCUMENT: "document"
    :vartype DOCUMENT: str
    :cvar SMARTPHONE: "smartphone"
    :vartype SMARTPHONE: str
    :cvar CAMERA: "camera"
    :vartype CAMERA: str
    :cvar SCISSORS: "scissors"
    :vartype SCISSORS: str
    :cvar COGS: "cogs"
    :vartype COGS: str
    :cvar BUBBLE: "bubble"
    :vartype BUBBLE: str
    :cvar UPARROW: "uparrow"
    :vartype UPARROW: str
    :cvar CHECKBOX: "checkbox"
    :vartype CHECKBOX: str
    :cvar SIGNPOST: "signpost"
    :vartype SIGNPOST: str
    :cvar SHUFFLE: "shuffle"
    :vartype SHUFFLE: str
    :cvar ADDRESSBOOK: "addressbook"
    :vartype ADDRESSBOOK: str
    :cvar LINEGRAPH: "linegraph"
    :vartype LINEGRAPH: str
    :cvar PICTURE: "picture"
    :vartype PICTURE: str
    :cvar CAR: "car"
    :vartype CAR: str
    :cvar WORLD: "world"
    :vartype WORLD: str
    :cvar SEARCH: "search"
    :vartype SEARCH: str
    :cvar CLIP: "clip"
    :vartype CLIP: str
    :cvar SOUND: "sound"
    :vartype SOUND: str
    :cvar BRUSH: "brush"
    :vartype BRUSH: str
    :cvar KEY: "key"
    :vartype KEY: str
    :cvar PADLOCK: "padlock"
    :vartype PADLOCK: str
    :cvar PRICETAG: "pricetag"
    :vartype PRICETAG: str
    :cvar SUITCASE: "suitcase"
    :vartype SUITCASE: str
    :cvar FINISH: "finish"
    :vartype FINISH: str
    :cvar PLANE: "plane"
    :vartype PLANE: str
    :cvar LOOP: "loop"
    :vartype LOOP: str
    :cvar WIFI: "wifi"
    :vartype WIFI: str
    :cvar TRUCK: "truck"
    :vartype TRUCK: str
    :cvar CART: "cart"
    :vartype CART: str
    :cvar BULB: "bulb"
    :vartype BULB: str
    :cvar BELL: "bell"
    :vartype BELL: str
    :cvar PRESENTATION: "presentation"
    :vartype PRESENTATION: str
    """

    TASK = "task"
    EMAIL = "email"
    MEETING = "meeting"
    DEADLINE = "deadline"
    CALL = "call"
    LUNCH = "lunch"
    CALENDAR = "calendar"
    DOWNARROW = "downarrow"
    DOCUMENT = "document"
    SMARTPHONE = "smartphone"
    CAMERA = "camera"
    SCISSORS = "scissors"
    COGS = "cogs"
    BUBBLE = "bubble"
    UPARROW = "uparrow"
    CHECKBOX = "checkbox"
    SIGNPOST = "signpost"
    SHUFFLE = "shuffle"
    ADDRESSBOOK = "addressbook"
    LINEGRAPH = "linegraph"
    PICTURE = "picture"
    CAR = "car"
    WORLD = "world"
    SEARCH = "search"
    CLIP = "clip"
    SOUND = "sound"
    BRUSH = "brush"
    KEY = "key"
    PADLOCK = "padlock"
    PRICETAG = "pricetag"
    SUITCASE = "suitcase"
    FINISH = "finish"
    PLANE = "plane"
    LOOP = "loop"
    WIFI = "wifi"
    TRUCK = "truck"
    CART = "cart"
    BULB = "bulb"
    BELL = "bell"
    PRESENTATION = "presentation"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, DataIconKey2._member_map_.values()))


@JsonMap({"id_": "id"})
class AddActivityTypeOkResponseData(BaseModel):
    """AddActivityTypeOkResponseData

    :param id_: The ID of the activity type, defaults to None
    :type id_: int, optional
    :param name: The name of the activity type, defaults to None
    :type name: str, optional
    :param icon_key: Icon graphic to use for representing this activity type, defaults to None
    :type icon_key: DataIconKey2, optional
    :param color: A designated color for the activity type in 6-character HEX format (e.g. `FFFFFF` for white, `000000` for black), defaults to None
    :type color: str, optional
    :param order_nr: An order number for the activity type. Order numbers should be used to order the types in the activity type selections., defaults to None
    :type order_nr: int, optional
    :param key_string: A string that is generated by the API based on the given name of the activity type upon creation, defaults to None
    :type key_string: str, optional
    :param active_flag: The active flag of the activity type, defaults to None
    :type active_flag: bool, optional
    :param is_custom_flag: Whether the activity type is a custom one or not, defaults to None
    :type is_custom_flag: bool, optional
    :param add_time: The creation time of the activity type, defaults to None
    :type add_time: str, optional
    :param update_time: The update time of the activity type, defaults to None
    :type update_time: str, optional
    """

    def __init__(
        self,
        id_: int = None,
        name: str = None,
        icon_key: DataIconKey2 = None,
        color: str = None,
        order_nr: int = None,
        key_string: str = None,
        active_flag: bool = None,
        is_custom_flag: bool = None,
        add_time: str = None,
        update_time: str = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = name
        if icon_key is not None:
            self.icon_key = self._enum_matching(
                icon_key, DataIconKey2.list(), "icon_key"
            )
        if color is not None:
            self.color = color
        if order_nr is not None:
            self.order_nr = order_nr
        if key_string is not None:
            self.key_string = key_string
        if active_flag is not None:
            self.active_flag = active_flag
        if is_custom_flag is not None:
            self.is_custom_flag = is_custom_flag
        if add_time is not None:
            self.add_time = add_time
        if update_time is not None:
            self.update_time = update_time


@JsonMap({})
class AddActivityTypeOkResponse(BaseModel):
    """AddActivityTypeOkResponse

    :param success: If the response is successful or not, defaults to None
    :type success: bool, optional
    :param data: data, defaults to None
    :type data: AddActivityTypeOkResponseData, optional
    """

    def __init__(
        self, success: bool = None, data: AddActivityTypeOkResponseData = None
    ):
        if success is not None:
            self.success = success
        if data is not None:
            self.data = self._define_object(data, AddActivityTypeOkResponseData)
